@@ -724,6 +724,7 @@ pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.lu", true);
+pref("network.IDN.whitelist.lv", true);
 pref("network.IDN.whitelist.no", true);
 pref("network.IDN.whitelist.nu", true);
 pref("network.IDN.whitelist.nz", true);
@@ -752,6 +753,9 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// lk, Sri Lanka, .<Lanka> and .<Ilangai>
+pref("network.IDN.whitelist.xn--fzc2c9e2c", true);
+pref("network.IDN.whitelist.xn--xkc2al3hye2a", true);
 // qa, Qatar, .<Qatar>
 pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
@@ -761,11 +765,14 @@ pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true);
 pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
 pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
 pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// sy, Syria, .<Souria>
+pref("network.IDN.whitelist.xn--ogbpf8fl", true);
 // tw, Taiwan, <.Taiwan> with variants
 pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
 pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
+pref("network.IDN.whitelist.asia", true);
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
@@ -851,7 +858,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 875 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 882 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1272,15 +1279,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1693 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 1700 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
-//@line 2117 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2124 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
-//@line 2320 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2327 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
-//@line 2416 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2423 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
-//@line 2419 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2426 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1550,15 +1557,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2691 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2698 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
-//@line 2759 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2766 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
-//@line 2785 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2792 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
-//@line 2805 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2812 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
-//@line 2813 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2820 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1595,9 +1602,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2855 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2862 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
-//@line 2860 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
+//@line 2867 "/builds/slave/rel-192-lnx-bld/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
